'use strict';

var core = require('@shikijs/core');
var engineJavascript = require('@shikijs/engine-javascript');
var php = require('../node_modules/shiki/dist/langs/php.js');
var tsx = require('../node_modules/shiki/dist/langs/tsx.js');
var typescript = require('../node_modules/shiki/dist/langs/typescript.js');

var __async = (__this, __arguments, generator) => {
  return new Promise((resolve, reject) => {
    var fulfilled = (value) => {
      try {
        step(generator.next(value));
      } catch (e) {
        reject(e);
      }
    };
    var rejected = (value) => {
      try {
        step(generator.throw(value));
      } catch (e) {
        reject(e);
      }
    };
    var step = (x) => x.done ? resolve(x.value) : Promise.resolve(x.value).then(fulfilled, rejected);
    step((generator = generator.apply(__this, __arguments)).next());
  });
};
function log(message, ...args) {
  {
    console.log(`[ShikiContext] ${message}`, ...args);
  }
}
const LANGS = {
  php,
  tsx,
  typescript
};
let highlighterInstance = null;
function getHighlighter() {
  return __async(this, null, function* () {
    if (highlighterInstance) {
      log("Returning cached highlighter instance");
      return highlighterInstance;
    }
    log("Creating new highlighter instance...");
    log("Initializing JavaScript regex engine...");
    const engine = engineJavascript.createJavaScriptRegexEngine();
    log("Engine created successfully");
    log("Loading required languages...");
    const langs = Object.values(LANGS).flat();
    log("Languages loaded successfully");
    log("Creating highlighter core...");
    highlighterInstance = yield core.createHighlighterCore({
      langs,
      engine
    });
    log("Highlighter core created successfully");
    log("Highlighter initialization complete");
    return highlighterInstance;
  });
}

exports.LANGS = LANGS;
exports.getHighlighter = getHighlighter;
//# sourceMappingURL=SyntaxContext.js.map
