/* eslint-disable no-console */
import { createHighlighterCore, type HighlighterCore } from '@shikijs/core'
import { createJavaScriptRegexEngine } from '@shikijs/engine-javascript'
import php from 'shiki/dist/langs/php.mjs'
import tsx from 'shiki/dist/langs/tsx.mjs'
import typescript from 'shiki/dist/langs/typescript.mjs'

const DEBUG = true
function log(message: string, ...args: any[]) {
  if (DEBUG) {
    console.log(`[ShikiContext] ${message}`, ...args)
  }
}

// Map of all available languages
export const LANGS = {
  php,
  tsx,
  typescript,
} as const

let highlighterInstance: HighlighterCore | null = null

export async function getHighlighter() {
  if (highlighterInstance) {
    log('Returning cached highlighter instance')
    return highlighterInstance
  }

  log('Creating new highlighter instance...')
  log('Initializing JavaScript regex engine...')
  const engine = createJavaScriptRegexEngine()
  log('Engine created successfully')

  log('Loading required languages...')
  // Get all language registrations from imports
  const langs = Object.values(LANGS).flat()
  log('Languages loaded successfully')

  log('Creating highlighter core...')
  highlighterInstance = await createHighlighterCore({
    langs,
    engine,
  })
  log('Highlighter core created successfully')

  log('Highlighter initialization complete')
  return highlighterInstance
}

// Clean up function if needed
export function disposeHighlighter() {
  if (highlighterInstance) {
    highlighterInstance.dispose()
    highlighterInstance = null
  }
}
